@@ -3,7 +3,6 @@ from logging import basicConfig, getLogger
 from time import sleep
 from typing import Any, List, Union, Tuple, Sequence, Sized
 
-from _lowlev_config import __version__
 import numpy as np
 from pandas import DataFrame, Series
 from ta.volatility import AverageTrueRange
@@ -38,6 +37,28 @@ BUY: PREDICT_TYPE = 1
 SELL: PREDICT_TYPE = 0
 EXIT: PREDICT_TYPE = 2
 
+__version__: str = "5.1.3"
+__author__: str = 'Vlad Kochetov'
+__credits__: List[str] = ["Hemerson Tacon -- Stack overflow",
+                          "hpaulj -- Stack overflow",
+                          "furas -- Stack overflow",
+                          "Devin Jeanpierre (edit: wjandrea) -- Stack overflow",
+                          "Войтенко Николай Поликарпович (Vojtenko Nikolay Polikarpovich) -- helped me test the "
+                          "system of interaction with the binance crypto exchange with 50 dollars.",
+
+                          "https://fxgears.com/index.php?threads/how-to-acquire-free-historical-tick-and-bar-data-for"
+                          "-algo-trading-and-backtesting-in-2020-stocks-forex-and-crypto-currency.1229/#post-19305"
+                          " -- binance get historical data method",
+                          "https://www.geeksforgeeks.org/python-different-ways-to-kill-a-thread/ and "
+                          "https://teletype.in/@cozy_codespace/Hk70-Ntl4 -- heroku and threading problems",
+                          "https://stackoverflow.com/questions/57838939/handling-exceptions-with-bulk-api-requests --"
+                          "IEX token",
+                          "Igor Kroitor -- donate 0.5 ETH (~1320$)",
+                          "Igor Kroitor -- Helped to solve the problem with exception ConnectionError(10054).",
+                          "https://stackoverflow.com/questions/27333671/how-to-solve-the-10054-error",
+                          "Pavel Fedotov (https://github.com/Pfed-prog) -- pull request https://github.com/"
+                          "VladKochetov007/quick_trade/pull/60"]
+
 logger = getLogger(__name__)
 getLogger('ccxt').setLevel(30)
 getLogger('urllib3').setLevel(30)
@@ -176,6 +197,7 @@ def convert_signal_str(predict: PREDICT_TYPE) -> str:
     elif predict == EXIT:
         return 'Exit'
 
+
 def get_exponential_growth(dataset: Sequence[float]) -> np.ndarray:
     return_list: List[float] = []
     coef = profit_factor(dataset)
@@ -272,11 +294,14 @@ def wait_success(func):
 
     return checker
 
+
 def root(x: float, pwr: float = 2) -> float:
-    return x ** (1/pwr)
+    return x ** (1 / pwr)
+
 
 def profit_factor(deposit_list: Sequence) -> float:
-    return root(deposit_list[-1]/deposit_list[0], len(deposit_list)-1)
+    return root(deposit_list[-1] / deposit_list[0], len(deposit_list) - 1)
+
 
 def assert_logger(func):
     @wraps(func)
@@ -286,4 +311,5 @@ def assert_logger(func):
         except AssertionError as AE:
             logger.critical(AE)
             raise AE
+
     return wrapper
